Class: Crucible::Tests::ConnectathonFinancialTrackTest
Constant Summary
Constants inherited from BaseSuite
Constants inherited from BaseTest
BaseTest::BASE_SPEC_LINK, BaseTest::JSON_FIELDS, BaseTest::METADATA_FIELDS, BaseTest::REST_SPEC_LINK, BaseTest::STATUS
Instance Attribute Summary
Attributes inherited from BaseTest
#category, #tags, #tests_subset, #warnings
Instance Method Summary collapse
- #description ⇒ Object
- #id ⇒ Object
-
#initialize(client1, client2 = nil) ⇒ ConnectathonFinancialTrackTest
constructor
A new instance of ConnectathonFinancialTrackTest.
- #setup ⇒ Object
- #teardown ⇒ Object
Methods inherited from BaseSuite
#build_messages, #collect_metadata, fhir_resources, #links, #metadata, #parse_operation_outcome, #requires, #resource_category, test, #title, #validates
Methods inherited from BaseTest
#author, #details, #execute, #execute_test_method, #execute_test_methods, #ignore_client_exception, #multiserver, #requires_authorization, #tests, #warning
Methods included from Assertions
#assert, #assert_bundle_entry_count, #assert_bundle_response, #assert_bundle_transactions_okay, #assert_equal, #assert_etag_present, #assert_last_modified_present, #assert_minimum, #assert_navigation_links, #assert_operator, #assert_resource_content_type, #assert_resource_type, #assert_response_bad, #assert_response_code, #assert_response_conflict, #assert_response_created, #assert_response_gone, #assert_response_not_found, #assert_response_ok, #assert_valid_content_location_present, #assert_valid_profile, #assert_valid_resource_content_type_present, #assertion_negated, #skip
Constructor Details
#initialize(client1, client2 = nil) ⇒ ConnectathonFinancialTrackTest
Returns a new instance of ConnectathonFinancialTrackTest.
13 14 15 16 17 |
# File 'lib/tests/suites/connectathon_financial_track.rb', line 13 def initialize(client1, client2=nil) super(client1, client2) .append('connectathon') @category = {id: 'connectathon', title: 'Connectathon'} end |
Instance Method Details
#description ⇒ Object
9 10 11 |
# File 'lib/tests/suites/connectathon_financial_track.rb', line 9 def description 'Connectathon Financial Track Test focuses on submitting Claims and retreiving ClaimResponses.' end |
#id ⇒ Object
5 6 7 |
# File 'lib/tests/suites/connectathon_financial_track.rb', line 5 def id 'ConnectathonFinancialTrackTest' end |
#setup ⇒ Object
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/tests/suites/connectathon_financial_track.rb', line 19 def setup @resources = Crucible::Generator::Resources.new @simple = @resources.simple_claim @simple.id = nil # clear the identifier, in case the server checks for duplicates @simple.identifier = nil # clear the identifier, in case the server checks for duplicates @average = @resources.average_claim @average.id = nil # clear the identifier, in case the server checks for duplicates @average.identifier = nil # clear the identifier, in case the server checks for duplicates @preauth = @resources.complex_claim @preauth.id = nil # clear the identifier, in case the server checks for duplicates @preauth.identifier = nil # clear the identifier, in case the server checks for duplicates @er = @resources.load_fixture('financial/eligibilityrequest-example.xml') @er.id = nil @er.identifier = nil @patient = @resources.minimal_patient @patient.id = nil @patient.identifier = [FHIR::Identifier.new] @patient.identifier[0].value = SecureRandom.urlsafe_base64 result = @client.create(@patient) assert_response_ok(result) @patient_id = result.id @simple.patient.reference = "Patient/#{@patient_id}" @average.patient.reference = "Patient/#{@patient_id}" @preauth.patient.reference = "Patient/#{@patient_id}" @er.patient.reference = "Patient/#{@patient_id}" @organization_1 = @resources.example_patient_record_organization_201 @organization_1.id = nil reply = @client.create @organization_1 @organization_1_id = reply.id @organization_1.id = @organization_1_id assert_response_ok(reply) @simple.organization.reference = "Organization/#{@organization_1_id}" @average.organization.reference = "Organization/#{@organization_1_id}" @preauth.organization.reference = "Organization/#{@organization_1_id}" @er.organization.reference = "Organization/#{@organization_1_id}" @organization_2 = @resources.example_patient_record_organization_203 @organization_2.id = nil reply = @client.create @organization_2 @organization_2_id = reply.id @organization_2.id = @organization_2_id assert_response_ok(reply) @simple.insurer.reference = "Organization/#{@organization_2_id}" @average.insurer.reference = "Organization/#{@organization_2_id}" @preauth.insurer.reference = "Organization/#{@organization_2_id}" @er.insurer.reference = "Organization/#{@organization_2_id}" end |
#teardown ⇒ Object
77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/tests/suites/connectathon_financial_track.rb', line 77 def teardown @client.destroy(FHIR::Claim, @simple_id) if !@simple_id.nil? @client.destroy(FHIR::Claim, @preauth_id) if !@preauth_id.nil? @client.destroy(FHIR::Claim, @average_id) if !@average_id.nil? @client.destroy(FHIR::ClaimResponse, @simple_response_id) if !@simple_response_id.nil? @client.destroy(FHIR::ClaimResponse, @average_response_id) if !@average_response_id.nil? @client.destroy(FHIR::ClaimResponse, @preauth_response_id) if !@preauth_response_id.nil? @client.destroy(FHIR::Patient, @patient_id) if !@patient_id.nil? @client.destroy(FHIR::Patient, @organization_1_id) if !@organization_1_id.nil? @client.destroy(FHIR::Patient, @organization_2_id) if !@organization_2_id.nil? @client.destroy(FHIR::EligibilityRequest, @er_id) if !@er_id.nil? @client.destroy(FHIR::Communication, @preauth_communication_id) if !@preauth_communication_id.nil? end |